@@ -167,7 +167,7 @@ def flag_test_func(title=None):
         there will be other string before file path
         and some editor cannot jump to the location.
     '''
-    msg = 'This place have codes for test!'
+    msg = 'There are test codes in this place!'
     current_frame = inspect.getouterframes(inspect.currentframe())[1]
     print('\n    '+gen_line_info(current_frame))
 
